pub enum GeneratedQrProgress {
QrReady(QrCodeData),
QrScanned(CheckCodeSender),
}Available on crate feature
e2e-encryption only.Expand description
Metadata to be used with LoginProgress::EstablishingSecureChannel and
GrantLoginProgress::EstablishingSecureChannel when this device is the
one generating the QR code.
We have established the secure channel, but we need to let the other device
know about the QrCodeData so they can connect to the channel and let us
know about the check code so we can verify that the channel is indeed
secure.
Variants
QrReady(QrCodeData)
The QR code has been created and this device is waiting for the other device to scan it.
QrScanned(CheckCodeSender)
The QR code has been scanned by the other device and this device is waiting for the user to put in the check code displayed on the other device.