GrantLoginProgress

Enum GrantLoginProgress 

pub enum GrantLoginProgress<Q> {
    Starting,
    EstablishingSecureChannel(Q),
    WaitingForAuth {
        verification_uri: Url,
        continuation_sender: ContinuationMessageSender,
    },
    SyncingSecrets,
    Done,
}
Available on crate feature e2e-encryption only.
The progress of granting the login.

Variants



Starting

We’re just starting up, this is the default and initial state.



EstablishingSecureChannel(Q)

The secure channel is being established by exchanging the QR code and/or [CheckCode].



WaitingForAuth

The secure channel has been confirmed using the [CheckCode] and this device is waiting for the authorization to complete.

Fields

verification_uri: Url

A URI to open in a (secure) system browser to verify the new login.

continuation_sender: ContinuationMessageSender

A sender to confirm that the authorization using the verification URI has been started in the browser and that the application is ready to proceed. This allows applications that suspend or navigate away while the verification URI is open to resume the process explicitly.



SyncingSecrets

The new device has been granted access and this device is sending the secrets to it.



Done

The process is complete.