pub enum MessageDecodeError {
Ecies(EciesMessageDecodeError),
Utf8(Utf8Error),
Json(Error),
}Available on crate feature
e2e-encryption only.Expand description
Error type which describes failures when messages which are received over the secure channel fail to be decoded.
Variants
Ecies(EciesMessageDecodeError)
A received message has failed to be decoded.
Utf8(Utf8Error)
A message we received over the secure channel was not a valid UTF-8 encoded string.
Json(Error)
A message couldn’t be deserialized from JSON.