pub enum SecureChannelError {
Decryption(DecryptionError),
MessageDecode(MessageDecodeError),
SecureChannelMessage {
expected: &'static str,
received: String,
},
InvalidCheckCode,
RendezvousChannel(HttpError),
InvalidIntent,
CannotReceiveCheckCode,
UnsupportedQrCodeType,
}Available on crate feature
e2e-encryption only.Expand description
Error type for failures in when receiving or sending messages over the secure channel.
Variants
Decryption(DecryptionError)
A message has failed to be decrypted.
MessageDecode(MessageDecodeError)
A received message has failed to be decoded.
SecureChannelMessage
The secure channel failed to be established because it received an unexpected message.
Fields
InvalidCheckCode
The secure channel could not have been established, the check code was invalid.
RendezvousChannel(HttpError)
An error happened in the underlying rendezvous channel.
InvalidIntent
Both devices have advertised the same intent in the login attempt, i.e. both sides claim to be a new device.
CannotReceiveCheckCode
The secure channel could not have been established, the check code cannot be received.
UnsupportedQrCodeType
The QR code specifies an unsupported protocol version.