CheckCodeSender

Type Alias CheckCodeSender 

pub type CheckCodeSender = CloneableSender<u8>;
Available on crate feature e2e-encryption only.
A oneshot sender used to send the check code back to the device that generated the QR code.

Aliased Type

pub struct CheckCodeSender { /* private fields */ }

Implementations

Source

impl CheckCodeSender

pub async fn send(&self, check_code: u8) -> Result<(), SenderError>

Send the check code.

Calling this method more than once will result in an error.

Arguments
  • check_code - The check code in digits representation.