pub struct ContinuationMessageSender(/* private fields */);Available on crate feature
e2e-encryption only.Expand description
Struct used to let the QR code granting logic know that it can continue with the process since applications might suspend things while the verification URI is open.
Implementations
Sourceimpl ContinuationMessageSender
impl ContinuationMessageSender
Sourcepub async fn confirm(&self) -> Result<(), SenderError>
pub async fn confirm(&self) -> Result<(), SenderError>
Confirm the continuation of the login granting process.
Sourcepub async fn cancel(&self) -> Result<(), SenderError>
pub async fn cancel(&self) -> Result<(), SenderError>
Cancel the login granting process.