pub type CheckCodeSender = CloneableSender<u8>;Available on crate feature
e2e-encryption only.Expand description
A oneshot sender used to send the check code back to the device that generated the QR code.
Aliased Type
pub struct CheckCodeSender { /* private fields */ }